'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _util = require('util');

var _util2 = _interopRequireDefault(_util);

var _httpCall = require('http-call');

var _httpCall2 = _interopRequireDefault(_httpCall);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = base => {
  return class HTTP extends _httpCall2.default {
    constructor(...args) {
      var _temp;

      return _temp = super(...args), this.headers = {
        'user-agent': `${base.config.name}/${base.config.version} node-${process.version}`
      }, _temp;
    }

    async request() {
      this.logRequest();
      await super.request();
      this.logResponse();
    }

    renderHeaders(headers) {
      return Object.keys(headers).map(key => {
        let value = key.toUpperCase() === 'AUTHORIZATION' ? 'REDACTED' : headers[key];
        return '    ' + key + '=' + value;
      }).join('\n');
    }

    logRequest() {
      if (!base.config.debug) return;
      base.stderr.log(`--> ${this.method} ${this.url}`);
      if (base.config.debug > 1) {
        base.stderr.log(this.renderHeaders(this.headers));
        // if (body) this.error(`--- BODY\n${util.inspect(body)}\n---`)
      }
    }

    logResponse() {
      if (!base.config.debug) return;
      base.stderr.log(`<-- ${this.method} ${this.url} ${this.response.statusCode}`);
      if (base.config.debug > 1) {
        base.stderr.log(this.renderHeaders(this.response.headers));
        if (this.body) base.stderr.log(`--- BODY\n${_util2.default.inspect(this.body)}\n---`);
      }
    }
  };
};